@@ -1,7 +1,5 @@
-get_site_data_from_pedon_db <-
-function(dsn)
-  {
-  q <- "SELECT site.siteiid, pedon.peiid, site.usiteid as site_id, pedon.upedonid as pedon_id, siteobs.obsdate as obs_date,
+get_site_data_from_pedon_db <- function(dsn) {
+  q <- "SELECT site.siteiid, pedon.peiid, site.usiteid as site_id, siteobs.obsdate as obs_date,
   latdegrees + IIF(IsNull(latminutes), 0.0, latminutes/ 60.0) + IIF(IsNULL(latseconds), 0.0, latseconds / 60.0 / 60.0) as y,
   -(longdegrees + IIF(IsNull(longminutes), 0.0, longminutes / 60.0) + IIF(IsNull(longseconds), 0.0, longseconds / 60.0 / 60.0)) as x,
   dm.choice as datum, descname as describer, pp.choice as pedon_purpose, soinmassamp as sampled_as, soinmascorr as correlated_as, pedlabsampnum, psctopdepth, pscbotdepth, ps.choice_label as part_size_class, ts.choice_label as tax_subgroup, elev, slope, aspect, plantassocnm, bedrckdepth, br.choice_label as bedrock_kind, hs.choice AS hillslope_pos 
@@ -28,7 +26,6 @@ function(dsn)
   channel <- odbcConnectAccess(dsn, readOnlyOptimize=TRUE)
 
   # exec query
-  cat(paste('fetching from', dsn, '...\n'))
   d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
 
   # close connection
